==> qbs_1.7.0+dfsg.orig.tar.gz: qbs-src-1.7.0/src/lib/corelib/language/scriptimporter.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qbs.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU Lesser General Public License version 3 requirements
** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 2.0 or (at your option) the GNU General
** Public license version 3 or any later version approved by the KDE Free
** Qt Foundation. The licenses are as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-2.0.html and
** https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/

#ifndef SCRIPTIMPORTER_H
#define SCRIPTIMPORTER_H

#include <QHash>
#include <QScriptEngine>

namespace qbs {
namespace Internal {

class ScriptImporter
{
public:
    ScriptImporter(QScriptEngine *scriptEngine);
    void importSourceCode(const QString &sourceCode, const QString &filePath, QScriptValue &targetObject);

private:
    static void copyProperties(const QScriptValue &src, QScriptValue &dst);

    QScriptEngine *m_engine;
    QHash<QString, QString> m_sourceCodeCache;
};

} // namespace Internal
} // namespace qbs

#endif // SCRIPTIMPORTER_H

==> qbs_1.10.1+dfsg.orig.tar.gz: qbs-src-1.10.1/src/lib/corelib/language/scriptimporter.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qbs.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU Lesser General Public License version 3 requirements
** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 2.0 or (at your option) the GNU General
** Public license version 3 or any later version approved by the KDE Free
** Qt Foundation. The licenses are as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-2.0.html and
** https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/

#ifndef SCRIPTIMPORTER_H
#define SCRIPTIMPORTER_H

#include <QtCore/qhash.h>

#include <QtScript/qscriptvalue.h>

namespace qbs {
namespace Internal {

class ScriptEngine;

class ScriptImporter
{
public:
    ScriptImporter(ScriptEngine *scriptEngine);
    void importSourceCode(const QString &sourceCode, const QString &filePath, QScriptValue &targetObject);

private:
    static void copyProperties(const QScriptValue &src, QScriptValue &dst);

    ScriptEngine *m_engine;
    QHash<QString, QString> m_sourceCodeCache;
};

} // namespace Internal
} // namespace qbs

#endif // SCRIPTIMPORTER_H
